import { Application, Router } from "oak";
import React from "react";
import ReactDOMServer from "react-dom/server";
import App from "/app.tsx";
import { ServerStyleSheet } from 'styled-components'


const Bundle = {JS:"", CSS:"", HTML:""};

Deno.emit("./src/app_client.tsx", {
  bundle: "classic",
  compilerOptions: { lib: ["dom", "dom.iterable", "esnext"] },
  importMapPath: "./importmap.json",
}).then(result => 
{
  Bundle.JS = result.files["deno:///bundle.js"];
  console.log("bundle built");
});


const router = new Router();
router.get("/", (context) => {
  console.log("serving page");

  let sheet = new ServerStyleSheet();
  Bundle.HTML = ReactDOMServer.renderToString(sheet.collectStyles(<App/>));
  Bundle.CSS = sheet.getStyleTags();
  sheet.seal();

  context.response.body =
`<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    ${Bundle.CSS}
</head>
<body>
    <h1>v 2.0</h1>
    <div id="root">${Bundle.HTML}</div>
    <script>${Bundle.JS}</script>
</body>
</html>`;
});


const app = new Application();
app.use(router.routes());
app.use(router.allowedMethods());
app.listen({ port:8000 });
console.log("server running");